/*
  ArdubotLib.cpp - Library for using Ardubot.Ru Module
*/
	
/*
 * Written by Konstantin Kostyuk et al., Jan 21, 2010.
 * Copyright (c) 2010 4Robots. For more information, see
 * Ver: 0.1 21.01.2010
 * Ver: 0.2 29.01.2010
 *
 *   http://www.4Robots.ru
 *   http://www.Ardubot.ru
 *
 * You may freely modify and share this code, as long as you keep this
 * notice intact (including the two links above).  Licensed under the
 * Creative Commons BY-SA 3.0 license:
 *
 *   http://creativecommons.org/licenses/by-sa/3.0/
 *
 */

#ifndef F_CPU
#define F_CPU 8000000UL
#endif
#include <avr/io.h>
#include <stdlib.h>
#include "ArdubotLib.h"
#include "WProgram.h"
#include "wiring.h"		// provides access to delay() and delayMicroseconds()

// constructor

ArdubotMotors::ArdubotMotors()
{
	  cSpeedM1 = MOTOR_OFF; //current speed for motor 1
    cSpeedM2 = MOTOR_OFF; //current speed for motor 2
    StepPWM = 1; //step into milisec for PWM regulate
	  
	  pinMode(PIN_DIR_1A, OUTPUT);// sets the digital pin as output 
  	pinMode(PIN_PWM_2A, OUTPUT);// sets the digital pin as output 

	  pinMode(PIN_DIR_1B, OUTPUT);// sets the digital pin as output 
  	pinMode(PIN_PWM_2B, OUTPUT);// sets the digital pin as output 
  	
  	digitalWrite(PIN_DIR_1A, MOTOR_OFF);
  	analogWrite(PIN_PWM_2A, cSpeedM1);	
  	
  	digitalWrite(PIN_DIR_1B, MOTOR_OFF);
  	analogWrite(PIN_PWM_2B, cSpeedM2);		
}


// sets the motor speed.  The sign of 'speed' determines the direction
// and the magnitude determines the speed.  limits: -255 <= speed < 255
// |speed| = 255 produces the maximum speed while speed = 0 is full brake.
void ArdubotMotors::setM1Speed(int speed)
{
	unsigned char reverse = 0;

	cSpeedM1 = speed; //save speed
	if (speed < 0)
	{
		speed = -speed;	// make speed a positive quantity
		reverse = 1;	// preserve the direction
	}
	if (speed > 0xFF)	// 0xFF = 255
		speed = 0xFF;

	digitalWrite(PIN_DIR_1A, reverse);
  analogWrite(PIN_PWM_2A, speed);	
}


void ArdubotMotors::setM2Speed(int speed)
{
	unsigned char reverse = 0;

	cSpeedM2 = speed; //save speed
	if (speed < 0)
	{
		speed = -speed;	// make speed a positive quantity
		reverse = 1;	// preserve the direction
	}
	if (speed > 0xFF)	// 0xFF = 255
		speed = 0xFF;

	digitalWrite(PIN_DIR_1B, reverse);
  analogWrite(PIN_PWM_2B, speed);	
}

int ArdubotMotors::getM1Speed()
{
	return cSpeedM1;
}

int ArdubotMotors::getM2Speed()
{
	return cSpeedM2;
}

void ArdubotMotors::setM1SpeedPWM(int speed)
{
	unsigned char reverse = 0;

	while (speed = cSpeedM1)
	{
		if (speed > cSpeedM1)
			cSpeedM1++;//current speed(cSpeedM1) less then speed
		else
		  cSpeedM1--;//current speed(cSpeedM1) more then speed	
		  
		setM1Speed(cSpeedM1);
		delay(StepPWM);
	}
}

void ArdubotMotors::setM2SpeedPWM(int speed)
{
	unsigned char reverse = 0;

	while (speed = cSpeedM2)
	{
		if (speed > cSpeedM2)
			cSpeedM2++;//current speed(cSpeedM2) less then speed
		else
		  cSpeedM2--;//current speed(cSpeedM2) more then speed	
		  
		setM1Speed(cSpeedM2);
		delay(StepPWM);		
	}
}

void ArdubotMotors::setSpeeds(int m1Speed, int m2Speed)
{
	setM1Speed(m1Speed);
	setM2Speed(m2Speed);
}

void  ArdubotMotors::setSpeedsPWM(int m1Speed, int m2Speed)
{
	setM1SpeedPWM(m1Speed);
	setM2SpeedPWM(m2Speed);	
}
  
// Local Variables: **
// mode: C++ **
// c-basic-offset: 4 **
// tab-width: 4 **
// indent-tabs-mode: t **
// end: **
